pub trait Response {
// Required method
fn to_response(&self) -> HttpResponse;
}Expand description
Trait that allows things to be sent back from the server
pub trait Response {
// Required method
fn to_response(&self) -> HttpResponse;
}Trait that allows things to be sent back from the server