Module server

Module server 

The actual http server on which you define your routes

Structs

HttpServer
The struct to initialise your http server and finally listen on some port

Enums

ServerError

Traits

HandlerFn
A generic trait to allow many different types of handlers to be passed into our http server

Type Aliases

Handler
MiddleWareFn