ClientErrorResponse

Enum ClientErrorResponse 

#[non_exhaustive]
pub enum ClientErrorResponse {
Show 29 variants BadRequest = 400, Unauthorized = 401, PaymentRequired = 402, Forbidden = 403, NotFound = 404, MethodNotAllowed = 405, NotAcceptable = 406, ProxyAuthenticationRequired = 407, RequestTimeout = 408, Conflict = 409, Gone = 410, LengthRequired = 411, PreconditionFailed = 412, PayloadTooLarge = 413, URITooLong = 414, UnsupportedMediaType = 415, RangeNotSatisfiable = 416, ExpectationFailed = 417, ImATeapot = 418, MisdirectedRequest = 421, UnprocessableContent = 422, Locked = 423, FailedDependency = 424, TooEarly = 425, UpgradeRequired = 426, PreconditionRequired = 428, TooManyRequests = 429, RequestHeaderFieldsTooLarge = 431, UnavailableForLegalReasons = 451,
}
Wikipedia:

A ClientErrorResponse (4xx) status code is for situations in which an error seems to have been caused by the client. Except when responding to a HEAD request, the server should include an entity containing an explanation of the error situation, and whether it is a temporary or permanent condition. These status codes are applicable to any request method. User agents should display any included entity to the user.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


BadRequest = 400



Unauthorized = 401



PaymentRequired = 402



Forbidden = 403



NotFound = 404



MethodNotAllowed = 405



NotAcceptable = 406



ProxyAuthenticationRequired = 407



RequestTimeout = 408



Conflict = 409



Gone = 410



LengthRequired = 411



PreconditionFailed = 412



PayloadTooLarge = 413



URITooLong = 414



UnsupportedMediaType = 415



RangeNotSatisfiable = 416



ExpectationFailed = 417



ImATeapot = 418



MisdirectedRequest = 421



UnprocessableContent = 422



Locked = 423



FailedDependency = 424



TooEarly = 425



UpgradeRequired = 426



PreconditionRequired = 428



TooManyRequests = 429



RequestHeaderFieldsTooLarge = 431



UnavailableForLegalReasons = 451