HttpStatus

Enum HttpStatus 

#[non_exhaustive]
pub enum HttpStatus { Informational(InformationalResponse), Success(SuccessResponse), Redirection(RedirectionResponse), ClientError(ClientErrorResponse), ServerError(ServerErrorResponse), }
Wikipedia:

The status code is a three-digit, decimal, integer value that represents the disposition of the server’s attempt to satisfy the client’s request. Generally, a client handles a response primarily based on the status code and secondarily on response header fields. A client may not understand each status code that a server reports but it must understand the class as indicated by the first digit and treat an unrecognized code as equivalent to the x00 code of that class.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


Informational(InformationalResponse)

Status range 1xx - See InformationalResponse for more info



Success(SuccessResponse)

Status range 2xx - See SuccessResponse for more info



Redirection(RedirectionResponse)

Status range 3xx - See RedirectionResponse for more info



ClientError(ClientErrorResponse)

Status range 4xx - See ClientErrorResponse for more info



ServerError(ServerErrorResponse)

Status range 5xx - See ServerErrorResponse for more info

Implementations

Source

impl HttpStatus

pub const INTERNAL_SERVER_ERROR: Self

pub const UNAUTHORIZED: Self

pub const NOT_FOUND: Self

pub const FORBIDDEN: Self

pub const BAD_REQUEST: Self

pub const TOO_MANY_REQUESTS: Self

pub const OK: Self

pub const MOVED_PERMANENTLY: Self