#[non_exhaustive]pub enum InformationalResponse {
SwitchingProtocols = 101,
Processing = 102,
EarlyHints = 103,
}Expand description
Wikipedia:
an InformationalResponse (1xx) indicates that the request was received and understood and is being processed. It alerts the client to wait for a final response. The message does not contain a body. As the HTTP/1.0 standard did not define any 1xx status codes, servers must not send a 1xx response to an HTTP/1.0 compliant client except under experimental conditions.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.