ServerErrorResponse

Enum ServerErrorResponse 

#[non_exhaustive]
pub enum ServerErrorResponse { InternalServerError = 500, NotImplemented = 501, BadGateway = 502, ServiceUnavailable = 503, GatewayTimeout = 504, HTTPVersionNotSupported = 505, VariantAlsoNegotiates = 506, InsufficientStorage = 507, LoopDetected = 508, NotExtended = 510, NetworkAuthenticationRequired = 511, }
Wikipedia:

A ServerErrorResponse (5xx) status indicates that the server is aware that it has encountered an error or is otherwise incapable of performing the request. Except when responding to a HEAD request, the server should include an entity containing an explanation of the error situation, and indicate whether it is a temporary or permanent condition. Likewise, user agents should display any included entity to the user. These response codes are applicable to any request method.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InternalServerError = 500



NotImplemented = 501



BadGateway = 502



ServiceUnavailable = 503



GatewayTimeout = 504



HTTPVersionNotSupported = 505



VariantAlsoNegotiates = 506



InsufficientStorage = 507



LoopDetected = 508



NotExtended = 510



NetworkAuthenticationRequired = 511